.. _reference:

Reference
=========

This is the class and function reference of cyipopt. Please refer to the
:ref:`tutorial <tutorial>` for further details, as the class and function raw
specifications may not be enough to give full guidelines on their uses.

.. autoclass:: cyipopt.Problem
   :members:

.. autoclass:: cyipopt.problem

.. autofunction:: cyipopt.minimize_ipopt

.. autofunction:: cyipopt.set_logging_level

.. autofunction:: cyipopt.setLoggingLevel

.. autoclass:: cyipopt.CyIpoptEvaluationError
